Crate rael

Crate rael 

A simple terminal rendering engine for creating text-based UIs and games.

Structs

Canvas
A canvas for drawing to the terminal, like a digital picasso.
Color
Represents an RGB color with red, green, and blue components.
CompositedCell
Represents a single terminal character cell after compositing half-block pixels. This is used for differential rendering, storing the final top and bottom colors that will be displayed in a single terminal character cell.
TerminalPixel
Represents a single half-block pixel with a specific color.